@@ -46,13 +46,9 @@
             x=L_a-L_b; y=L_a-L_c; z=L_b-L_c;
             if(y!=0&&z!=0){
                 s=a*L_b*L_c/(x*y)-b*L_a*L_c/(x*z)+c*L_a*L_b/(y*z); //inverse quad interpolation
-                //cout << setprecision(DIGITS);
-                //cout << "quad:     " << s << endl;
             }
             else{
                 s=b-L_b*(b-a)/(L_b-L_a); //secant rule
-                //cout << setprecision(DIGITS);
-                //cout << "secant:   " << s << endl;
             }
 
             if(a<b){
@@ -63,8 +59,6 @@
             }
             if ((s<tmp||s>tmp2) || (my_flag &&my_norm(s-b)>= my_norm(b-c) / 2) || (!my_flag && my_norm(s-b)>=my_norm(c-d)/2)){
                 s=(a+b)/2; my_flag=true;
-                //cout << setprecision(DIGITS);
-                //cout << "midpoint: " << s << endl;
             }
             else my_flag=false;
 
@@ -87,10 +81,6 @@
         // sqrt(v*v+1) is only good for zeta. Other L-functions have more
         // precision loss.
 
-        //if(abs(L_b)>tolerance*1000)
-        //    cout << "Mofu. Big zero  " << b << " " <<L_b<<endl;
-
-
         return(b);
 
 
@@ -159,7 +149,6 @@
                 }
                 else
                 {
-                    //file << tmp2 << endl;
                     file << message_stamp << " ";
                     if(tmp_DIGITS<DIGITS)
                         file << setprecision(tmp_DIGITS);
@@ -254,7 +243,6 @@
             h2=h1;
             h1=h1*5;
             x=abs(value(.5+h1));
-            //cout << x << " multiply by 5, at " << h1<<endl;
         }while(x<1.e-9&&h1<2);
         if(x>1.e-8){
             do{
@@ -262,7 +250,6 @@
                     tmp_h=h1;
                     h1=(h1+h2)/2;
                     x=abs(value(.5+h1));
-                    //cout << x << " divide and conquer, at " << h1<<endl;
                 }while(x>1.e-8);
                 if(x<1.e-9)
                 {
@@ -271,10 +258,8 @@
                 }
             }while(x<1.e-9);
         }
-        //y=abs(value(.5+h2));
         y=x;
         x=abs(value(.5+1.01*h1));
-        //cout << h1<< " " << x << " " << y << " "<<(log(x)-log(y))/log(1.01)<<endl;
         r = Int(rint(lcalc_to_double(abs(log(x)-log(y)))/log(1.01)));
         if(print_rank||my_verbose>3) cout << "#                analytic rank equals "<< r << endl;
         return (r);
@@ -290,8 +275,6 @@
         if(rank!=analytic_rank)
             cout<< "given rank "<<rank<< " is different than computed analytic rank "<<
         analytic_rank <<endl;
-        //else
-        //cout<< "given rank "<<rank<< " equals analytic rank"<<endl;
     }
 
 
@@ -336,12 +319,6 @@
         xxx_local_density=Nmain(xxx_T+1.)-Nmain(xxx_T); //N(T) counts zeros in |t|<T, so the length of the interval in question is 2. However,
                                                         //our array stores zeros above and below the axis, so that's okay
 
-        //double theta=0;
-        //for(j=1;j<=a;j++)
-        //{
-            //theta = theta+gamma[j];
-        //}
-        //degree=(int)(2*theta);
 
         xxx_number_zeros = 2*Int(10+DIGITS*xxx_local_density); //we need to multiply by 2 since we want the distance to the zero being tested to exceed Digits
         //and we are taking zeros above and below that zero.
@@ -373,13 +350,6 @@
         else analytic_rank=compute_rank();
 
 
-        /* should now be okay to take start_N<analytic_rank, so this error is not used
-        if(start_N<analytic_rank){
-            cout << "error: start_N (=" << start_N << " ) needs to be > analytic_rank (="<< analytic_rank << ")." << endl;
-            exit(1);
-        }
-        */
-
         bool do_negative=is_complex(); //controls whether to look for zeros below real axis too.
 
         Double start_T; //height at which to start searching for (N+1)st, (N+2)nd, etc zeros
@@ -519,7 +489,7 @@
         int found_missing=0; //number missing zeros found
         int to_find=0; //number of missing zeros to find
         Double x2,y2,u2,v2,tmp2=0.,tmp3=0.,tmp4; //used to search for missing zeros
-        Double x3=0.,x3_c=0.,u3;
+        Double x3=0.,x3_c=0.,u3=0;
         Double x_c=1,y_c=1,x2_c=1,y2_c=1; //used to search for zeros below the real axis
         int number_insert; //1 or 2 according to whether we find zeros below and/or above real axis
 
@@ -538,7 +508,7 @@
         cout << setprecision(DIGITS3);
 
         //count multiplicity of zero at 0, then start slightly higher.
-        //doesn't matter if I miss a zero inbetween, since this
+        //doesn't matter if I miss a zero in between, since this
         //will then be detected by N(T) comparison and searched for.
 
 
@@ -638,7 +608,6 @@
                 for(i=ii;i>=ii-15;i--){
                     local_average=local_average+zeros_S[i][1]/16;
                 }
-                //cout << "local average: " << ii << " " << local_average << endl;
 
                 if(local_average>.7) to_find=1;
                 if(local_average>1.5) to_find=Int(local_average+.5);
@@ -746,20 +715,18 @@
                                             zeros_S[j][0]=zeros_S[j-number_insert][0];
                                             zeros_S[j][2]=zeros_S[j-number_insert][2];
                                             zeros_S[j][1]=zeros_S[j-number_insert][1]-number_insert;
-                                        //cout << "        AAAA: " << zeros_S[j][0]*zeros_S[j][2] << endl;
+
                                         }
                                         if(number_insert==1&&sn(x2)!=sn(y2)){
                                             zeros_S[i+1][0]=tmp2;
                                             zeros_S[i+1][2]=1;
                                             zeros_S[i+1][1]=zeros_S[i+2][1]-1; //not strictly correct, but close enough
-                                        //cout << "        BBBB: " << zeros_S[i+1][0]*zeros_S[i+1][2] << endl;
 //XXXXXXXXXXXXX do this more precisely.don't be lazy!
                                         }
                                         else if(number_insert==1&&sn(x2_c)!=sn(y2_c)){
                                             zeros_S[i+1][0]=tmp3;
                                             zeros_S[i+1][2]=-1;
                                             zeros_S[i+1][1]=zeros_S[i+2][1]-1; //not strictly correct, but close enough
-                                        //cout << "        CCCC: " << zeros_S[i+1][0]*zeros_S[i+1][2] << endl;
 //XXXXXXXXXXXXX do this more precisely.don't be lazy!
                                         }
                                         else{
@@ -769,12 +736,10 @@
                                             zeros_S[i+1][0]=tmp2;
                                             zeros_S[i+1][2]=1;
                                             zeros_S[i+1][1]=zeros_S[i+2][1]-1; //not strictly correct, but close enough
-                                        //cout << "        DDDD: " << zeros_S[i+1][0]*zeros_S[i+1][2] << endl;
 
                                         }
 
                                         i=i-2*number_insert;if(i<1)i=1;
-                                        //cout << "i = " << i << " zeros_S[i+1]: " << zeros_S[i+1][2]*zeros_S[i+1][0] << endl;
 
 
                                     }
@@ -784,10 +749,8 @@
 
                             }while(v2<zeros_S[i+1][0]);
 
-                            //cout << "IIII = " << i << " zeros_S[i+1]: " << zeros_S[i+1][2]*zeros_S[i+1][0] << endl;
                             //in the do_negative case, there is one final sign change check needed
                             if(also_do_end_pt&&!just_found&&found_missing<to_find&&do_negative&&zeros_S[i+1][2]>0){
-                            //if(also_do_end_pt&&found_missing==0&&do_negative&&zeros_S[i+1][2]>0){
                                 v2=zeros_S[i+1][0];
 
                                 y2_c=real(value(.5-I*v2,0,"rotated pure"));
@@ -807,12 +770,10 @@
                                         zeros_S[j][0]=zeros_S[j-1][0];
                                         zeros_S[j][2]=zeros_S[j-1][2];
                                         zeros_S[j][1]=zeros_S[j-1][1]-1;
-                                        //cout << "        here: " << zeros_S[j][0]*zeros_S[j][2] << endl;
                                     }
                                     zeros_S[i+1][0]=tmp3;
                                     zeros_S[i+1][2]=-1;
                                     zeros_S[i+1][1]=zeros_S[i+2][1]-1;
-                                    //cout << "        here insert: " << zeros_S[i+1][0]*zeros_S[i+1][2] << endl;
 
                                     i=i-2;if(i<1)i=1;
                                  }
@@ -820,7 +781,6 @@
 
                             } //if(do_negative&&zeros_S[i+1][2]>0)
                             else if(also_do_end_pt&&!just_found&&found_missing<to_find&&do_negative&&zeros_S[i+1][2]<0){
-                            //else if(also_do_end_pt&&found_missing==0&&do_negative&&zeros_S[i+1][2]<0){
                                 v2=zeros_S[i+1][0];
                                 y2=real(value(.5+I*v2,0,"rotated pure"));
 
@@ -877,12 +837,15 @@
 
             ii+=found_missing; found_missing=0;
 
-            //double check for duplicates amongst neighbours (due to finite precision, on rare occasion
-            //the same zero is mistaken as two separate zeros), and, to be safe, also next to neighbours
-            //in the case of not self dual. Remove if needed. If there are duplicates, dumping of zeros 
-            //is delayed until the next time around or later.
+            // double check for duplicates amongst neighbours (due to
+            // finite precision, on rare occasion the same zero is
+            // mistaken as two separate zeros), and, to be safe, also
+            // next to neighbours in the case of not self dual. Remove
+            // if needed. If there are duplicates, dumping of zeros is
+            // delayed until the next time around or later.
 
-            //Make sure not to run this code on actual duplicates at s=1/2, i.e. when the rank is positive.
+            // Make sure not to run this code on actual duplicates at
+            // s=1/2, i.e. when the rank is positive.
             bool duplicates=false;
             int starting_i;
             if (analytic_rank>0) starting_i=analytic_rank+1;
@@ -940,11 +903,7 @@
 
                 i=1;
                 do{
-                    //int tmp_DIGITS = Int(DIGITS3+log(zeros_S[i][0]+2)/2.3)+1;
 
-
-
-                    //if(do_test_explicit_formula){
                         if(!xxx_half_full&&xxx_count<xxx_number_zeros/2){ //initially fill up half of the xxx_zeros array
                              xxx_zeros[xxx_count]=zeros_S[i][0]*zeros_S[i][2];
                              xxx_count++;
@@ -964,10 +923,18 @@
 
                              xxx_flag=0;
                              if(start_N<=analytic_rank||count2>(1+do_negative)*xxx_number_zeros/2){
-                                 if(!xxx_full||count2%5==0){ //run the test on the first few zeros and then every 5th zero
-                                     //add .5 so as to de-symmetrize the test function, i.e. not an even function. That makes the test more sensitive
-                                     //to errors in the zero upon which we are centering since linear terms then appear in the Taylor expansion
-                                     //wrt to the error of the centered zero.
+                                 if(!xxx_full||count2%5==0){
+				   // run the test on the first few
+				   // zeros and then every 5th zero
+				   // add .5 so as to de-symmetrize
+				   // the test function, i.e. not an
+				   // even function. That makes the
+				   // test more sensitive to errors in
+				   // the zero upon which we are
+				   // centering since linear terms
+				   // then appear in the Taylor
+				   // expansion wrt to the error of
+				   // the centered zero.
                                      xxx_flag = test_explicit_formula(xxx_zeros[xxx_current_zero]+.5, xxx_alpha,xxx_zeros,xxx_number_zeros_test,xxx_log_diff_coeffs,100,"hermite",0); //the zero at the end is for the hermite function of order 0, i.e. Gaussian exponential
                                      xxx_called=true;
                                  }
@@ -980,8 +947,6 @@
                                  cout << zeros_S[i][0]*zeros_S[i][2] << endl;
                                  for(i=0;i<xxx_number_zeros;i++){
                                      cout << xxx_zeros[i] << endl;
-                                     //cout << zeros_S[i][0]*zeros_S[i][2] << " , S(T) approx: " << zeros_S[i][1];
-                                     //cout <<  " , L value: " << value(.5+I*zeros_S[i][0]*zeros_S[i][2]) << endl;
                                  }
                                  exit(1);
                              }
@@ -1014,50 +979,21 @@
 			    result->push_back(zeros_S[i][0]*zeros_S[i][2]);
 			}
 
-                        //XXXXXXXXXXXXXX added for debugging purposes
-                        //if(my_verbose==-1) cout << " " << setprecision(6) << " " << value(.5+I*zeros_S[i][0]*zeros_S[i][2]) << " " << zeros_S[i][1]; 
-                        //if(i>1&&my_verbose==-1&&abs(zeros_S[i-1][0]-zeros_S[i][0])< exp(-2.3*(DIGITS3-3))) cout <<
-                        //"XXXXXXXXX close zeros detected XXXXXXX " << i << " " << zeros_S[i-1][0] << " " << zeros_S[i][0];
                     }
 
                     i++;
                 }while(i<=10&&count2<count);
 
 
-/*
-            //check that the explicit formula is satisfied using a test function that picks out local zeros.
-            //test function is exp(-alpha(x-x_0-.5)^2) where , here, we set alpha=2.3/Digits, x_0 = current_zero,
-            // the -.5 is to desymmetrize the test function so that it is not even about x_0, and thus has linear
-            //term in it's Taylor expansion.
-
-            //We basically want to detect anomalies as we spit out zeros one at a time.
-
-            if(do_negative){
-                for(i=1;i<=50;i++) xxx_zeros[i-1]=zeros_S[i][0]*zeros_S[i][2];
-                //xxx_alpha = 2.3*DIGITS3/my_norm(xxx_zeros[49]-xxx_zeros[0]); 
-                xxx_flag = test_explicit_formula(xxx_alpha,xxx_zeros[0], xxx_zeros,50);
-            }
-
-            if(xxx_flag==1){
-                cout << "WARNING: FAILURE OF THE EXPLICIT FORMULA. DUMPING ZEROS AND QUITTING." << endl;
-                cout << setprecision(DIGITS);
-                for(i=1;i<=50;i++)
-                cout << zeros_S[i][0]*zeros_S[i][2] << " " << zeros_S[i][1]<< endl;
-                exit(1);
-             }
-
-*/
-
                 for(i=11;i<=ii;i++){
                     zeros_S[i-10][0]=zeros_S[i][0];
                     zeros_S[i-10][2]=zeros_S[i][2];
                     zeros_S[i-10][1]=zeros_S[i][1];
-                    //cout << "find zeros: shifting: " << i << " " << zeros_S[i][0] <<endl;
+
                 }
                 cout << setprecision(DIGITS3);
                 ii=ii-10;
             }
-            //}
             previous_zero=tmp;
 
             u=t;
